==> haskell-hledger-lib-1.4-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.4
id: hledger-lib-1.4-6UswAxbdMFNJnYLaMe6wyo
key: hledger-lib-1.4-6UswAxbdMFNJnYLaMe6wyo
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.AutoTransaction
    Hledger.Data.Commodity Hledger.Data.Dates Hledger.Data.Journal
    Hledger.Data.Ledger Hledger.Data.MarketPrice Hledger.Data.Period
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.Types Hledger.Query
    Hledger.Read Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.JournalReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.BalanceHistoryReport Hledger.Reports.BalanceReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReports
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.TransactionsReports Hledger.Utils
    Hledger.Utils.Color Hledger.Utils.Debug Hledger.Utils.Parse
    Hledger.Utils.Regex Hledger.Utils.String Hledger.Utils.Test
    Hledger.Utils.Text Hledger.Utils.Tree Hledger.Utils.UTF8IOCompat
    Text.Megaparsec.Compat
hidden-modules: Paths_hledger_lib
abi: 504f9e0aec239a487a6aa56a849dbe94
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-lib-1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-lib-1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hledger-lib-1.4
hs-libraries: HShledger-lib-1.4-6UswAxbdMFNJnYLaMe6wyo
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE array-0.5.2.0
    blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu bytestring-0.10.8.2
    cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf containers-0.5.10.2
    csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT
    data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65
    Decimal-0.4.2-7mRD3xJAgOuJ0IazPguQMz deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    hashtables-1.2.2.1-D96UtOZkClK2Kw64wd465
    megaparsec-6.2.0-ELO2VroTI7qKq1GmQfjUii
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus
    parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
    pretty-show-1.6.13-Kr7jKj0IStAHwpp9cTcOWv
    regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj time-1.8.0.2
    transformers-0.5.2.0 uglymemo-0.1.0.1-1Sek1g9jwwELZwNwbCGwJf
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE=de59792f66ffb61bd5cb2ed7de76d387
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu=60bf71ffdbd66c0260456518da98a9ef
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf=d2ead4026b00faa2638870c5a7f7348b
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT=be166ca37d31f068df6973a78755b37e
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=82f3b4ad59d56e7fb1579643899ebf63
             Decimal-0.4.2-7mRD3xJAgOuJ0IazPguQMz=e9c5f3d9e58ecb9ce0d408c299d7fe75
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             hashtables-1.2.2.1-D96UtOZkClK2Kw64wd465=aee64be66244633897c71e095f727987
             megaparsec-6.2.0-ELO2VroTI7qKq1GmQfjUii=0b3c9b80ece8959273eebb7ecb35d244
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=6e88558dac665c66c2d7d633e15999e5
             parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1=ac5e6b578591765d59beabaa71c9486d
             pretty-show-1.6.13-Kr7jKj0IStAHwpp9cTcOWv=0ad10fa816ce04fa5d9a8d75e0683588
             regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8=49cee3c3b864e7a4b170da8a226077c5
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=863c6a42773abd5c980b4318cc858c44
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=614819b9f074e058df73dc3c520cf25f
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             uglymemo-0.1.0.1-1Sek1g9jwwELZwNwbCGwJf=dfa307c8abd49102a896dfb48cba1f72
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hledger-lib-1.4-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.4
id: hledger-lib-1.4-BH2O6R5DdY75LqZi8WmTYw
key: hledger-lib-1.4-BH2O6R5DdY75LqZi8WmTYw
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.AutoTransaction
    Hledger.Data.Commodity Hledger.Data.Dates Hledger.Data.Journal
    Hledger.Data.Ledger Hledger.Data.MarketPrice Hledger.Data.Period
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.Types Hledger.Query
    Hledger.Read Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.JournalReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.BalanceHistoryReport Hledger.Reports.BalanceReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReports
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.TransactionsReports Hledger.Utils
    Hledger.Utils.Color Hledger.Utils.Debug Hledger.Utils.Parse
    Hledger.Utils.Regex Hledger.Utils.String Hledger.Utils.Test
    Hledger.Utils.Text Hledger.Utils.Tree Hledger.Utils.UTF8IOCompat
    Text.Megaparsec.Compat
hidden-modules: Paths_hledger_lib
abi: 5be3afa52392bfc1eaf64f1868ae8e0b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-lib-1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/hledger-lib-1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hledger-lib-1.4
hs-libraries: HShledger-lib-1.4-BH2O6R5DdY75LqZi8WmTYw
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE array-0.5.2.0
    blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu bytestring-0.10.8.2
    cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf containers-0.5.10.2
    csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT
    data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65
    Decimal-0.4.2-7mRD3xJAgOuJ0IazPguQMz deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    hashtables-1.2.2.1-D96UtOZkClK2Kw64wd465
    megaparsec-6.3.0-9DWieIXXMEGE77cyJc2XIp
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus
    parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
    pretty-show-1.6.15-5cAvN2LPVLH9nYGqOguH1N
    regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj time-1.8.0.2
    transformers-0.5.2.0 uglymemo-0.1.0.1-1Sek1g9jwwELZwNwbCGwJf
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE=de59792f66ffb61bd5cb2ed7de76d387
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu=60bf71ffdbd66c0260456518da98a9ef
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf=d2ead4026b00faa2638870c5a7f7348b
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT=be166ca37d31f068df6973a78755b37e
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=82f3b4ad59d56e7fb1579643899ebf63
             Decimal-0.4.2-7mRD3xJAgOuJ0IazPguQMz=e9c5f3d9e58ecb9ce0d408c299d7fe75
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             hashtables-1.2.2.1-D96UtOZkClK2Kw64wd465=aee64be66244633897c71e095f727987
             megaparsec-6.3.0-9DWieIXXMEGE77cyJc2XIp=fd6f0a8200164e25afcdea0edbedf861
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=6e88558dac665c66c2d7d633e15999e5
             parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1=ac5e6b578591765d59beabaa71c9486d
             pretty-show-1.6.15-5cAvN2LPVLH9nYGqOguH1N=e045114cd7b00499872c375bc225b134
             regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8=49cee3c3b864e7a4b170da8a226077c5
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=863c6a42773abd5c980b4318cc858c44
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=614819b9f074e058df73dc3c520cf25f
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             uglymemo-0.1.0.1-1Sek1g9jwwELZwNwbCGwJf=dfa307c8abd49102a896dfb48cba1f72
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
